@@ -6,7 +6,7 @@ from typing import Union
 from napoleontoolbox.authentication import ClientCredentials, PasswordCredentials, Token
 
 
-class AbstractHeaders(metaclass=ABCMeta):
+class AbstractHeadersTemplate(metaclass=ABCMeta):
 
     @property
     @abstractmethod
@@ -18,6 +18,43 @@ class AbstractHeaders(metaclass=ABCMeta):
         raise NotImplemented
 
 
+class AbstractHeaders(AbstractHeadersTemplate):
+
+    @property
+    @abstractmethod
+    def value(self):
+        raise NotImplemented
+
+    @staticmethod
+    def build(object: Union[PasswordCredentials, ClientCredentials, Token]):
+        raise NotImplemented
+
+
+class AbstractHeadersScheme(AbstractHeadersTemplate):
+
+    @property
+    @abstractmethod
+    def value(self):
+        raise NotImplemented
+
+    @staticmethod
+    def build(object: Union[PasswordCredentials, ClientCredentials, Token]):
+        raise NotImplemented
+
+
+class HeadersScheme(AbstractHeadersTemplate):
+
+    def __init__(self):
+        self.__value = None
+
+    def value(self):
+        pass
+
+    @staticmethod
+    def build(object: Union[PasswordCredentials, ClientCredentials, Token]):
+        pass
+
+
 class TemplateHeaders(AbstractHeaders):
 
     def value(self): ...
@@ -36,15 +73,18 @@ class Headers(TemplateHeaders):
         return self.__value
 
     def __dict__(self):
-        return None
+        return self.__value
 
     @staticmethod
-    def build(object: Union[PasswordCredentials, ClientCredentials, Token]):
-        return HeaderGenerator().build(object)
+    def build(o: Union[PasswordCredentials, ClientCredentials, Token]):
+        return HeaderGenerator().build(o).value
+
+
+class AuthenticationHeader(TemplateHeaders):
+    pass
 
 
 class HeaderGenerator(AbstractHeaders):
-
     def __init__(self):
         self.__header = None
 
@@ -59,6 +99,4 @@ class HeaderGenerator(AbstractHeaders):
             return None
         elif isinstance(self.__header.content, Token):
             return None
-
-
-
+        return self
