@@ -71,7 +71,7 @@ class RessourceTemplate(AbsctractRessource):
 @config
 class Service(AbsctractRessource):
     def __init__(self):
-        self.__credentials = PasswordCredentials()
+        self.__credentials = ClientCredentials()
         self.__id = None
         self.__secret = None
         self.__type = None
@@ -99,7 +99,7 @@ class Service(AbsctractRessource):
         return self.__password
 
     def get_credentials(self):
-        return PasswordCredentials(self._id, self._secret, self._user, self._password)
+        return ClientCredentials(self._id, self._secret)
 
 
 @config
