@@ -675,7 +675,11 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
     wh['net_profit'] = wh.realized_pnl + wh.funding_fees_eth_usd + wh.funding_fees_xbt_usd + wh.trading_fees_eth_usd + wh.trading_fees_xbt_usd
     wh['valuation'] = wh.net_profit + wh.transfers_usd
     wh['valuation'] = wh.valuation.cumsum()
-    td = td.join(wh.iloc[:, 4:])
+
+    td['date'] = td.index
+
+    td = pd.merge(td, wh, how='left', left_on='date', right_on='date')
+
     td['amount_traded_usd_eth'] = td.traded_eth * td.avg_eth_price
     td['amount_traded_usd_btc'] = td.traded_xbt * td.avg_btc_price
 
